@@ -4,11 +4,11 @@ from typing import Union as _Union
 import numpy as _np
 import pandas as _pd
 
-from gnssanalysis import gn_aux as _gn_aux
-from gnssanalysis import gn_const as _gn_const
-from gnssanalysis import gn_datetime as _gn_datetime
-from gnssanalysis import gn_io as _gn_io
-from gnssanalysis import gn_plot as _gn_plot
+from . import gn_aux as _gn_aux
+from . import gn_const as _gn_const
+from . import gn_datetime as _gn_datetime
+from . import gn_io as _gn_io
+from . import gn_plot as _gn_plot
 
 
 def _valvar2diffstd(valvar1,valvar2,trace=True,std_coeff=1):
@@ -120,8 +120,9 @@ def _compare_nonsv_states(diffstd,log_lvl,tol=None):
     _logging.log(msg=f':diffutil [OK] non-SVs states diffs within the {"extracted STDs" if tol is None else f"{tol:.1E} tolerance"}',level=_logging.INFO)
     return 0
 
-def _compare_sat_postfit_residuals(diffstd,log_lvl,tol=None):
-    diff_count = diffstd[diffstd.attrs['SAT_MASK']].unstack(['TYPE','SAT','SITE','BLK'])
+
+def _compare_sat_postfit_residuals(diffstd, log_lvl, tol=None):
+    diff_count = diffstd[diffstd.attrs["SAT_MASK"]].unstack(["TYPE", "NUM", "SAT", "SITE", "BLK"])
     if diff_count.empty:
         _logging.warning(f':diffutil SVs residuals not present. Skipping')
         return 0
